"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.service_account_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetServiceAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the ServiceAccount resource to return.
    To get the service account ID, use a [ServiceAccountService.List] request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___GetServiceAccountRequest = GetServiceAccountRequest

@typing.final
class ListServiceAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list service accounts in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListServiceAccountsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListServiceAccountsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [ServiceAccount.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListServiceAccountsRequest = ListServiceAccountsRequest

@typing.final
class ListServiceAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListServiceAccountsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListServiceAccountsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def service_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.service_account_pb2.ServiceAccount]:
        """List of ServiceAccount resources."""

    def __init__(
        self,
        *,
        service_accounts: collections.abc.Iterable[yandex.cloud.iam.v1.service_account_pb2.ServiceAccount] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "service_accounts", b"service_accounts"]) -> None: ...

global___ListServiceAccountsResponse = ListServiceAccountsResponse

@typing.final
class CreateServiceAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a service account in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the service account.
    The name must be unique within the cloud.
    """
    description: builtins.str
    """Description of the service account."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateServiceAccountRequest = CreateServiceAccountRequest

@typing.final
class CreateServiceAccountMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account that is being created."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___CreateServiceAccountMetadata = CreateServiceAccountMetadata

@typing.final
class UpdateServiceAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the ServiceAccount resource to update.
    To get the service account ID, use a [ServiceAccountService.List] request.
    """
    name: builtins.str
    """Name of the service account.
    The name must be unique within the cloud.
    """
    description: builtins.str
    """Description of the service account."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the ServiceAccount resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "service_account_id", b"service_account_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateServiceAccountRequest = UpdateServiceAccountRequest

@typing.final
class UpdateServiceAccountMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the ServiceAccount resource that is being updated."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___UpdateServiceAccountMetadata = UpdateServiceAccountMetadata

@typing.final
class DeleteServiceAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to delete.
    To get the service account ID, use a [ServiceAccountService.List] request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___DeleteServiceAccountRequest = DeleteServiceAccountRequest

@typing.final
class DeleteServiceAccountMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account that is being deleted."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___DeleteServiceAccountMetadata = DeleteServiceAccountMetadata

@typing.final
class ListServiceAccountOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the ServiceAccount resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListServiceAccountOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListServiceAccountOperationsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListServiceAccountOperationsRequest = ListServiceAccountOperationsRequest

@typing.final
class ListServiceAccountOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListServiceAccountOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListServiceAccountOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified service account."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListServiceAccountOperationsResponse = ListServiceAccountOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/video_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/video_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import manifest_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_manifest__pb2
from yandex.cloud.video.v1 import video_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_video__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/video/v1/video_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/video/v1/manifest.proto\x1a!yandex/cloud/video/v1/video.proto\"1\n\x0fGetVideoRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb1\x01\n\x10ListVideoRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x1a\n\x08order_by\x18\x66 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"`\n\x11ListVideoResponse\x12,\n\x06videos\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.video.v1.Video\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"_\n\x15\x42\x61tchGetVideosRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\tvideo_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"F\n\x16\x42\x61tchGetVideosResponse\x12,\n\x06videos\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.video.v1.Video\"\xbd\x06\n\x12\x43reateVideoRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x05title\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=300\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=4000\x12\x1e\n\x0cthumbnail_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12<\n\x0e\x61uto_transcode\x18\x05 \x01(\x0e\x32$.yandex.cloud.video.v1.AutoTranscode\x12!\n\x0fstyle_preset_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x30\n\x0c\x61uto_publish\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tenable_ad\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x8a\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x35.yandex.cloud.video.v1.CreateVideoRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x37\n\x04tusd\x18\xe8\x07 \x01(\x0b\x32&.yandex.cloud.video.v1.VideoTUSDParamsH\x00\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessParamsH\x01\x12K\n\x0fsign_url_access\x18\xd3\x0f \x01(\x0b\x32/.yandex.cloud.video.v1.VideoSignURLAccessParamsH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\x42\x15\n\raccess_rights\x12\x04\xc0\xc1\x31\x01J\x04\x08\n\x10\x0bJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x06\x08\xd2\x0f\x10\xd3\x0fJ\x04\x08\t\x10\nJ\x05\x08\x0b\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xd0\x0f\"?\n\x0fVideoTUSDParams\x12\x19\n\tfile_size\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\x19\n\x17VideoPublicAccessParams\"\x1a\n\x18VideoSignURLAccessParams\"\'\n\x13\x43reateVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\xe4\x05\n\x12UpdateVideoRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x18\n\x05title\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=300\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=4000\x12\x1e\n\x0cthumbnail_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12<\n\x0e\x61uto_transcode\x18\x06 \x01(\x0e\x32$.yandex.cloud.video.v1.AutoTranscode\x12!\n\x0fstyle_preset_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12-\n\tenable_ad\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x8a\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x35.yandex.cloud.video.v1.UpdateVideoRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessParamsH\x00\x12K\n\x0fsign_url_access\x18\xd3\x0f \x01(\x0b\x32/.yandex.cloud.video.v1.VideoSignURLAccessParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\raccess_rightsJ\x04\x08\n\x10\x0bJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x06\x08\xd2\x0f\x10\xd3\x0fJ\x04\x08\t\x10\nJ\x05\x08\x0b\x10\xc8\x01J\x06\x08\xc9\x01\x10\xd0\x0f\"\'\n\x13UpdateVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\x97\x02\n\x15TranscodeVideoRequest\x12\x10\n\x08video_id\x18\x01 \x01(\t\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x14\n\x0csubtitle_ids\x18\x03 \x03(\t\x12M\n\x14translation_settings\x18\x04 \x01(\x0b\x32/.yandex.cloud.video.v1.VideoTranslationSettings\x12Q\n\x16summarization_settings\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.video.v1.VideoSummarizationSettings\"\xc6\x05\n\x18VideoTranslationSettings\x12P\n\x06tracks\x18\x01 \x03(\x0b\x32@.yandex.cloud.video.v1.VideoTranslationSettings.TranslationTrack\x1a\x86\x02\n\x10TranslationTrack\x12U\n\x0binput_track\x18\x01 \x01(\x0b\x32:.yandex.cloud.video.v1.VideoTranslationSettings.InputTrackB\x04\xe8\xc7\x31\x01\x12P\n\tsubtitles\x18\x02 \x03(\x0b\x32=.yandex.cloud.video.v1.VideoTranslationSettings.SubtitleTrack\x12I\n\x05\x61udio\x18\x03 \x03(\x0b\x32:.yandex.cloud.video.v1.VideoTranslationSettings.AudioTrack\x1au\n\nInputTrack\x12\x1c\n\x0btrack_index\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12I\n\x08src_lang\x18\x02 \x01(\tB7\xf2\xc7\x31,|ara|deu|eng|fra|ita|jpn|kor|rus|spa|tur|zho\x8a\xc8\x31\x03\x30,3\x1a\x80\x01\n\rSubtitleTrack\x12R\n\x08\x64st_lang\x18\x01 \x01(\tB@\xe8\xc7\x31\x01\xf2\xc7\x31\x33\x61ra|deu|eng|fra|ita|jpn|kaz|kor|rus|spa|tur|ukr|zho\x8a\xc8\x31\x01\x33\x12\x1b\n\x05label\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x1aU\n\nAudioTrack\x12*\n\x08\x64st_lang\x18\x01 \x01(\tB\x18\xe8\xc7\x31\x01\xf2\xc7\x31\x0b\x65ng|kaz|rus\x8a\xc8\x31\x01\x33\x12\x1b\n\x05label\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xfa\x02\n\x1aVideoSummarizationSettings\x12T\n\x06tracks\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.video.v1.VideoSummarizationSettings.SummarizationTrack\x12\x1a\n\x12process_all_tracks\x18\x03 \x01(\x08\x1am\n\x12SummarizationTrack\x12W\n\x0binput_track\x18\x01 \x01(\x0b\x32<.yandex.cloud.video.v1.VideoSummarizationSettings.InputTrackB\x04\xe8\xc7\x31\x01\x1au\n\nInputTrack\x12\x1c\n\x0btrack_index\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12I\n\x08src_lang\x18\x02 \x01(\tB7\xf2\xc7\x31,|ara|deu|eng|fra|ita|jpn|kor|rus|spa|tur|zho\x8a\xc8\x31\x03\x30,3J\x04\x08\x01\x10\x02\"*\n\x16TranscodeVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"4\n\x12\x44\x65leteVideoRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteVideoMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"b\n\x18\x42\x61tchDeleteVideosRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\tvideo_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\".\n\x19\x42\x61tchDeleteVideosMetadata\x12\x11\n\tvideo_ids\x18\x01 \x03(\t\"\xd4\x01\n\x19PerformVideoActionRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12=\n\x07publish\x18\xe8\x07 \x01(\x0b\x32).yandex.cloud.video.v1.PublishVideoActionH\x00\x12\x41\n\tunpublish\x18\xe9\x07 \x01(\x0b\x32+.yandex.cloud.video.v1.UnpublishVideoActionH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x05\x08\x02\x10\xe8\x07\"\x14\n\x12PublishVideoAction\"\x16\n\x14UnpublishVideoAction\".\n\x1aPerformVideoActionMetadata\x12\x10\n\x08video_id\x18\x01 \x01(\t\"\xb7\x01\n\x18GetVideoPlayerURLRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.yandex.cloud.video.v1.VideoPlayerParams\x12\x41\n\x1esigned_url_expiration_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"C\n\x11VideoPlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"=\n\x19GetVideoPlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t\"\xe5\x01\n\x1e\x42\x61tchGetVideoPlayerURLsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\tvideo_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\x12\x38\n\x06params\x18\x03 \x01(\x0b\x32(.yandex.cloud.video.v1.VideoPlayerParams\x12\x41\n\x1esigned_url_expiration_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"6\n\x1f\x42\x61tchGetVideoPlayerURLsResponse\x12\x13\n\x0bplayer_urls\x18\x01 \x03(\t\":\n\x18GetVideoManifestsRequest\x12\x1e\n\x08video_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"O\n\x19GetVideoManifestsResponse\x12\x32\n\tmanifests\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Manifest2\xa7\x0f\n\x0cVideoService\x12p\n\x03Get\x12&.yandex.cloud.video.v1.GetVideoRequest\x1a\x1c.yandex.cloud.video.v1.Video\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/video/v1/videos/{video_id}\x12s\n\x04List\x12\'.yandex.cloud.video.v1.ListVideoRequest\x1a(.yandex.cloud.video.v1.ListVideoResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/video/v1/videos\x12\x8d\x01\n\x08\x42\x61tchGet\x12,.yandex.cloud.video.v1.BatchGetVideosRequest\x1a-.yandex.cloud.video.v1.BatchGetVideosResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/video/v1/videos:batchGet:\x01*\x12\x93\x01\n\x06\x43reate\x12).yandex.cloud.video.v1.CreateVideoRequest\x1a!.yandex.cloud.operation.Operation\";\xb2\xd2*\x1c\n\x13\x43reateVideoMetadata\x12\x05Video\x82\xd3\xe4\x93\x02\x15\"\x10/video/v1/videos:\x01*\x12\x9e\x01\n\x06Update\x12).yandex.cloud.video.v1.UpdateVideoRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\x1c\n\x13UpdateVideoMetadata\x12\x05Video\x82\xd3\xe4\x93\x02 2\x1b/video/v1/videos/{video_id}:\x01*\x12\xb1\x01\n\tTranscode\x12,.yandex.cloud.video.v1.TranscodeVideoRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*\x1f\n\x16TranscodeVideoMetadata\x12\x05Video\x82\xd3\xe4\x93\x02*\"%/video/v1/videos/{video_id}:transcode:\x01*\x12\xab\x01\n\x06\x44\x65lete\x12).yandex.cloud.video.v1.DeleteVideoRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*,\n\x13\x44\x65leteVideoMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/video/v1/videos/{video_id}\x12\xc0\x01\n\x0b\x42\x61tchDelete\x12/.yandex.cloud.video.v1.BatchDeleteVideosRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*2\n\x19\x42\x61tchDeleteVideosMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!\"\x1c/video/v1/videos:batchDelete:\x01*\x12\xc1\x01\n\rPerformAction\x12\x30.yandex.cloud.video.v1.PerformVideoActionRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*#\n\x1aPerformVideoActionMetadata\x12\x05Video\x82\xd3\xe4\x93\x02.\")/video/v1/videos/{video_id}:performAction:\x01*\x12\xa3\x01\n\x0cGetPlayerURL\x12/.yandex.cloud.video.v1.GetVideoPlayerURLRequest\x1a\x30.yandex.cloud.video.v1.GetVideoPlayerURLResponse\"0\x82\xd3\xe4\x93\x02*\x12(/video/v1/videos/{video_id}:getPlayerURL\x12\xb3\x01\n\x12\x42\x61tchGetPlayerURLs\x12\x35.yandex.cloud.video.v1.BatchGetVideoPlayerURLsRequest\x1a\x36.yandex.cloud.video.v1.BatchGetVideoPlayerURLsResponse\".\x82\xd3\xe4\x93\x02(\"#/video/v1/videos:batchGetPlayerURLs:\x01*\x12\xa3\x01\n\x0cGetManifests\x12/.yandex.cloud.video.v1.GetVideoManifestsRequest\x1a\x30.yandex.cloud.video.v1.GetVideoManifestsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/video/v1/videos/{video_id}:getManifestsB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.video_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETVIDEOREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_GETVIDEOREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTVIDEOREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTVIDEOREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTVIDEOREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTVIDEOREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTVIDEOREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTVIDEOREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTVIDEOREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTVIDEOREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTVIDEOREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTVIDEOREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BATCHGETVIDEOSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHGETVIDEOSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHGETVIDEOSREQUEST'].fields_by_name['video_ids']._loaded_options = None
  _globals['_BATCHGETVIDEOSREQUEST'].fields_by_name['video_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEVIDEOREQUEST'].oneofs_by_name['source']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _globals['_CREATEVIDEOREQUEST'].oneofs_by_name['access_rights']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].oneofs_by_name['access_rights']._serialized_options = b'\300\3011\001'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\212\3101\005<=300'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=4000'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['thumbnail_id']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEVIDEOREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_VIDEOTUSDPARAMS'].fields_by_name['file_size']._loaded_options = None
  _globals['_VIDEOTUSDPARAMS'].fields_by_name['file_size']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['title']._serialized_options = b'\212\3101\005<=300'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=4000'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['thumbnail_id']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEVIDEOREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_TRANSCODEVIDEOREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_TRANSCODEVIDEOREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_VIDEOTRANSLATIONSETTINGS_TRANSLATIONTRACK'].fields_by_name['input_track']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_TRANSLATIONTRACK'].fields_by_name['input_track']._serialized_options = b'\350\3071\001'
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK'].fields_by_name['track_index']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK'].fields_by_name['track_index']._serialized_options = b'\372\3071\003>=1'
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK'].fields_by_name['src_lang']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK'].fields_by_name['src_lang']._serialized_options = b'\362\3071,|ara|deu|eng|fra|ita|jpn|kor|rus|spa|tur|zho\212\3101\0030,3'
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK'].fields_by_name['dst_lang']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK'].fields_by_name['dst_lang']._serialized_options = b'\350\3071\001\362\30713ara|deu|eng|fra|ita|jpn|kaz|kor|rus|spa|tur|ukr|zho\212\3101\0013'
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK'].fields_by_name['label']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK'].fields_by_name['label']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK'].fields_by_name['dst_lang']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK'].fields_by_name['dst_lang']._serialized_options = b'\350\3071\001\362\3071\013eng|kaz|rus\212\3101\0013'
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK'].fields_by_name['label']._loaded_options = None
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK'].fields_by_name['label']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_VIDEOSUMMARIZATIONSETTINGS_SUMMARIZATIONTRACK'].fields_by_name['input_track']._loaded_options = None
  _globals['_VIDEOSUMMARIZATIONSETTINGS_SUMMARIZATIONTRACK'].fields_by_name['input_track']._serialized_options = b'\350\3071\001'
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK'].fields_by_name['track_index']._loaded_options = None
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK'].fields_by_name['track_index']._serialized_options = b'\372\3071\003>=1'
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK'].fields_by_name['src_lang']._loaded_options = None
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK'].fields_by_name['src_lang']._serialized_options = b'\362\3071,|ara|deu|eng|fra|ita|jpn|kor|rus|spa|tur|zho\212\3101\0030,3'
  _globals['_DELETEVIDEOREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_DELETEVIDEOREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEVIDEOSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHDELETEVIDEOSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEVIDEOSREQUEST'].fields_by_name['video_ids']._loaded_options = None
  _globals['_BATCHDELETEVIDEOSREQUEST'].fields_by_name['video_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_PERFORMVIDEOACTIONREQUEST'].oneofs_by_name['action']._loaded_options = None
  _globals['_PERFORMVIDEOACTIONREQUEST'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_PERFORMVIDEOACTIONREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_PERFORMVIDEOACTIONREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETVIDEOPLAYERURLREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_GETVIDEOPLAYERURLREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST'].fields_by_name['video_ids']._loaded_options = None
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST'].fields_by_name['video_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_GETVIDEOMANIFESTSREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_GETVIDEOMANIFESTSREQUEST'].fields_by_name['video_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_VIDEOSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/video/v1/videos/{video_id}'
  _globals['_VIDEOSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/video/v1/videos'
  _globals['_VIDEOSERVICE'].methods_by_name['BatchGet']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['BatchGet']._serialized_options = b'\202\323\344\223\002\036\"\031/video/v1/videos:batchGet:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateVideoMetadata\022\005Video\202\323\344\223\002\025\"\020/video/v1/videos:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateVideoMetadata\022\005Video\202\323\344\223\002 2\033/video/v1/videos/{video_id}:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['Transcode']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['Transcode']._serialized_options = b'\262\322*\037\n\026TranscodeVideoMetadata\022\005Video\202\323\344\223\002*\"%/video/v1/videos/{video_id}:transcode:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteVideoMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/video/v1/videos/{video_id}'
  _globals['_VIDEOSERVICE'].methods_by_name['BatchDelete']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['BatchDelete']._serialized_options = b'\262\322*2\n\031BatchDeleteVideosMetadata\022\025google.protobuf.Empty\202\323\344\223\002!\"\034/video/v1/videos:batchDelete:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['PerformAction']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['PerformAction']._serialized_options = b'\262\322*#\n\032PerformVideoActionMetadata\022\005Video\202\323\344\223\002.\")/video/v1/videos/{video_id}:performAction:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['GetPlayerURL']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['GetPlayerURL']._serialized_options = b'\202\323\344\223\002*\022(/video/v1/videos/{video_id}:getPlayerURL'
  _globals['_VIDEOSERVICE'].methods_by_name['BatchGetPlayerURLs']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['BatchGetPlayerURLs']._serialized_options = b'\202\323\344\223\002(\"#/video/v1/videos:batchGetPlayerURLs:\001*'
  _globals['_VIDEOSERVICE'].methods_by_name['GetManifests']._loaded_options = None
  _globals['_VIDEOSERVICE'].methods_by_name['GetManifests']._serialized_options = b'\202\323\344\223\002*\022(/video/v1/videos/{video_id}:getManifests'
  _globals['_GETVIDEOREQUEST']._serialized_start=374
  _globals['_GETVIDEOREQUEST']._serialized_end=423
  _globals['_LISTVIDEOREQUEST']._serialized_start=426
  _globals['_LISTVIDEOREQUEST']._serialized_end=603
  _globals['_LISTVIDEORESPONSE']._serialized_start=605
  _globals['_LISTVIDEORESPONSE']._serialized_end=701
  _globals['_BATCHGETVIDEOSREQUEST']._serialized_start=703
  _globals['_BATCHGETVIDEOSREQUEST']._serialized_end=798
  _globals['_BATCHGETVIDEOSRESPONSE']._serialized_start=800
  _globals['_BATCHGETVIDEOSRESPONSE']._serialized_end=870
  _globals['_CREATEVIDEOREQUEST']._serialized_start=873
  _globals['_CREATEVIDEOREQUEST']._serialized_end=1702
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._serialized_start=1567
  _globals['_CREATEVIDEOREQUEST_LABELSENTRY']._serialized_end=1612
  _globals['_VIDEOTUSDPARAMS']._serialized_start=1704
  _globals['_VIDEOTUSDPARAMS']._serialized_end=1767
  _globals['_VIDEOPUBLICACCESSPARAMS']._serialized_start=1769
  _globals['_VIDEOPUBLICACCESSPARAMS']._serialized_end=1794
  _globals['_VIDEOSIGNURLACCESSPARAMS']._serialized_start=1796
  _globals['_VIDEOSIGNURLACCESSPARAMS']._serialized_end=1822
  _globals['_CREATEVIDEOMETADATA']._serialized_start=1824
  _globals['_CREATEVIDEOMETADATA']._serialized_end=1863
  _globals['_UPDATEVIDEOREQUEST']._serialized_start=1866
  _globals['_UPDATEVIDEOREQUEST']._serialized_end=2606
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._serialized_start=1567
  _globals['_UPDATEVIDEOREQUEST_LABELSENTRY']._serialized_end=1612
  _globals['_UPDATEVIDEOMETADATA']._serialized_start=2608
  _globals['_UPDATEVIDEOMETADATA']._serialized_end=2647
  _globals['_TRANSCODEVIDEOREQUEST']._serialized_start=2650
  _globals['_TRANSCODEVIDEOREQUEST']._serialized_end=2929
  _globals['_VIDEOTRANSLATIONSETTINGS']._serialized_start=2932
  _globals['_VIDEOTRANSLATIONSETTINGS']._serialized_end=3642
  _globals['_VIDEOTRANSLATIONSETTINGS_TRANSLATIONTRACK']._serialized_start=3043
  _globals['_VIDEOTRANSLATIONSETTINGS_TRANSLATIONTRACK']._serialized_end=3305
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK']._serialized_start=3307
  _globals['_VIDEOTRANSLATIONSETTINGS_INPUTTRACK']._serialized_end=3424
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK']._serialized_start=3427
  _globals['_VIDEOTRANSLATIONSETTINGS_SUBTITLETRACK']._serialized_end=3555
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK']._serialized_start=3557
  _globals['_VIDEOTRANSLATIONSETTINGS_AUDIOTRACK']._serialized_end=3642
  _globals['_VIDEOSUMMARIZATIONSETTINGS']._serialized_start=3645
  _globals['_VIDEOSUMMARIZATIONSETTINGS']._serialized_end=4023
  _globals['_VIDEOSUMMARIZATIONSETTINGS_SUMMARIZATIONTRACK']._serialized_start=3789
  _globals['_VIDEOSUMMARIZATIONSETTINGS_SUMMARIZATIONTRACK']._serialized_end=3898
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK']._serialized_start=3307
  _globals['_VIDEOSUMMARIZATIONSETTINGS_INPUTTRACK']._serialized_end=3424
  _globals['_TRANSCODEVIDEOMETADATA']._serialized_start=4025
  _globals['_TRANSCODEVIDEOMETADATA']._serialized_end=4067
  _globals['_DELETEVIDEOREQUEST']._serialized_start=4069
  _globals['_DELETEVIDEOREQUEST']._serialized_end=4121
  _globals['_DELETEVIDEOMETADATA']._serialized_start=4123
  _globals['_DELETEVIDEOMETADATA']._serialized_end=4162
  _globals['_BATCHDELETEVIDEOSREQUEST']._serialized_start=4164
  _globals['_BATCHDELETEVIDEOSREQUEST']._serialized_end=4262
  _globals['_BATCHDELETEVIDEOSMETADATA']._serialized_start=4264
  _globals['_BATCHDELETEVIDEOSMETADATA']._serialized_end=4310
  _globals['_PERFORMVIDEOACTIONREQUEST']._serialized_start=4313
  _globals['_PERFORMVIDEOACTIONREQUEST']._serialized_end=4525
  _globals['_PUBLISHVIDEOACTION']._serialized_start=4527
  _globals['_PUBLISHVIDEOACTION']._serialized_end=4547
  _globals['_UNPUBLISHVIDEOACTION']._serialized_start=4549
  _globals['_UNPUBLISHVIDEOACTION']._serialized_end=4571
  _globals['_PERFORMVIDEOACTIONMETADATA']._serialized_start=4573
  _globals['_PERFORMVIDEOACTIONMETADATA']._serialized_end=4619
  _globals['_GETVIDEOPLAYERURLREQUEST']._serialized_start=4622
  _globals['_GETVIDEOPLAYERURLREQUEST']._serialized_end=4805
  _globals['_VIDEOPLAYERPARAMS']._serialized_start=4807
  _globals['_VIDEOPLAYERPARAMS']._serialized_end=4874
  _globals['_GETVIDEOPLAYERURLRESPONSE']._serialized_start=4876
  _globals['_GETVIDEOPLAYERURLRESPONSE']._serialized_end=4937
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST']._serialized_start=4940
  _globals['_BATCHGETVIDEOPLAYERURLSREQUEST']._serialized_end=5169
  _globals['_BATCHGETVIDEOPLAYERURLSRESPONSE']._serialized_start=5171
  _globals['_BATCHGETVIDEOPLAYERURLSRESPONSE']._serialized_end=5225
  _globals['_GETVIDEOMANIFESTSREQUEST']._serialized_start=5227
  _globals['_GETVIDEOMANIFESTSREQUEST']._serialized_end=5285
  _globals['_GETVIDEOMANIFESTSRESPONSE']._serialized_start=5287
  _globals['_GETVIDEOMANIFESTSRESPONSE']._serialized_end=5366
  _globals['_VIDEOSERVICE']._serialized_start=5369
  _globals['_VIDEOSERVICE']._serialized_end=7328
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Partner(google.protobuf.message.Message):
    """A Partner resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Partner._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Partner._Status.ValueType  # 0
        UP: Partner._Status.ValueType  # 1
        DOWN: Partner._Status.ValueType  # 2

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Partner.Status.ValueType  # 0
    UP: Partner.Status.ValueType  # 1
    DOWN: Partner.Status.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the partner."""
    region_id: builtins.str
    """ID of the region that the partner belongs to."""
    status: global___Partner.Status.ValueType
    """Status of the partner."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        region_id: builtins.str = ...,
        status: global___Partner.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "region_id", b"region_id", "status", b"status"]) -> None: ...

global___Partner = Partner



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.saml.certificate_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to return.
    To get the certificate ID, make a [CertificateService.List] request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___GetCertificateRequest = GetCertificateRequest

@typing.final
class ListCertificatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to list certificates in.
    To get the federation ID make a [yandex.cloud.organizationmanager.v1.saml.FederationService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListCertificatesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListCertificatesResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Certificate.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCertificatesRequest = ListCertificatesRequest

@typing.final
class ListCertificatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCertificatesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListCertificatesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate]:
        """List of certificates."""

    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCertificatesResponse = ListCertificatesResponse

@typing.final
class CreateCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to add new certificate.
    To get the federation ID make a [yandex.cloud.organizationmanager.v1.saml.FederationService.List] request.
    """
    name: builtins.str
    """Name of the certificate.
    The name must be unique within the federation.
    """
    description: builtins.str
    """Description of the certificate."""
    data: builtins.str
    """Certificate data in PEM format."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "description", b"description", "federation_id", b"federation_id", "name", b"name"]) -> None: ...

global___CreateCertificateRequest = CreateCertificateRequest

@typing.final
class CreateCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate that is being created."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___CreateCertificateMetadata = CreateCertificateMetadata

@typing.final
class UpdateCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to update.
    To get the certificate ID, make a [CertificateService.List] request.
    """
    name: builtins.str
    """Name of the certificate.
    The name must be unique within the federation.
    """
    description: builtins.str
    """Description of the certificate."""
    data: builtins.str
    """Certificate data in PEM format."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the certificate are going to be updated."""

    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "data", b"data", "description", b"description", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateCertificateRequest = UpdateCertificateRequest

@typing.final
class UpdateCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate that is being updated."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___UpdateCertificateMetadata = UpdateCertificateMetadata

@typing.final
class DeleteCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to delete.
    To get the certificate ID, make a [CertificateService.List] request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___DeleteCertificateRequest = DeleteCertificateRequest

@typing.final
class DeleteCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate that is being deleted."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___DeleteCertificateMetadata = DeleteCertificateMetadata

@typing.final
class ListCertificateOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListCertificateOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListCertificateOperationsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCertificateOperationsRequest = ListCertificateOperationsRequest

@typing.final
class ListCertificateOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCertificateOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListCertificateOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified certificate."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListCertificateOperationsResponse = ListCertificateOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RuleSetDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RuleDescription(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        ANOMALY_SCORE_FIELD_NUMBER: builtins.int
        PARANOIA_LEVEL_FIELD_NUMBER: builtins.int
        id: builtins.str
        """ID of the rule"""
        anomaly_score: builtins.int
        """Numeric anomaly value, i.e., a potential attack indicator.
        The higher this value, the more likely it is that the request that satisfies the rule is an attack.
        See [documentation](/docs/smartwebsecurity/concepts/waf#anomaly).
        """
        paranoia_level: builtins.int
        """Paranoia level classifies rules according to their aggression.
        The higher the paranoia level, the better your protection, but also the higher the probability of WAF false positives.
        See [documentation](/docs/smartwebsecurity/concepts/waf#paranoia).
        """
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            anomaly_score: builtins.int = ...,
            paranoia_level: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["anomaly_score", b"anomaly_score", "id", b"id", "paranoia_level", b"paranoia_level"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the rule set"""
    version: builtins.str
    """Version of the rule set"""
    id: builtins.str
    """ID of the rule set"""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleSetDescriptor.RuleDescription]:
        """List of rules"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
        id: builtins.str = ...,
        rules: collections.abc.Iterable[global___RuleSetDescriptor.RuleDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "rules", b"rules", "version", b"version"]) -> None: ...

global___RuleSetDescriptor = RuleSetDescriptor



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.private_subnet_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the PrivateSubnet resource to return.

    To get the private subnet ID use a [PrivateSubnetService.List] request.
    """
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___GetPrivateSubnetRequest = GetPrivateSubnetRequest

@typing.final
class ListPrivateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list private subnets in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListConfigurationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListConfigurationsResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "name", "createdAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name", "zoneId", "hardwarePoolId"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPrivateSubnetRequest = ListPrivateSubnetRequest

@typing.final
class ListPrivateSubnetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListImagesRequest.page_size], use `next_page_token` as the value
    for the [ListImagesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def private_subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.private_subnet_pb2.PrivateSubnet]:
        """List of PrivateSubnet resources."""

    def __init__(
        self,
        *,
        private_subnets: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.private_subnet_pb2.PrivateSubnet] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_subnets", b"private_subnets"]) -> None: ...

global___ListPrivateSubnetResponse = ListPrivateSubnetResponse

@typing.final
class CreatePrivateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    VRF_OPTIONS_SPEC_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the private subnet.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the private subnet."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool where the private subnet resides.

    To get a list of available hardware pools, use the [HardwarePoolService.List] request.
    """
    folder_id: builtins.str
    """ID of the folder to create a private subnet in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    @property
    def vrf_options_spec(self) -> global___VrfOptionsSpec:
        """VRF options. Optional."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        vrf_options_spec: global___VrfOptionsSpec | None = ...,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["vrf_options_spec", b"vrf_options_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "labels", b"labels", "name", b"name", "vrf_options_spec", b"vrf_options_spec"]) -> None: ...

global___CreatePrivateSubnetRequest = CreatePrivateSubnetRequest

@typing.final
class VrfOptionsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VRF_ID_FIELD_NUMBER: builtins.int
    CIDR_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    GATEWAY_IP_FIELD_NUMBER: builtins.int
    vrf_id: builtins.str
    """ID of the VRF to create private subnet in.

    To get the VRF ID, use a [VrfService.List] request.
    """
    cidr: builtins.str
    """CIDR block.
    The range of internal addresses that are defined for this private subnet, as
    specified in [RFC1918](https://datatracker.ietf.org/doc/html/rfc1918#section-3).
    For example, 10.0.0.0/22 or 192.168.0.0/24.
    """
    gateway_ip: builtins.str
    """Gateway IP address for the subnet."""
    @property
    def dhcp_options(self) -> global___DhcpOptionsSpec:
        """DHCP options for the subnet.
        The absence or null value indicates that DHCP is disabled.
        """

    def __init__(
        self,
        *,
        vrf_id: builtins.str = ...,
        cidr: builtins.str = ...,
        dhcp_options: global___DhcpOptionsSpec | None = ...,
        gateway_ip: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr", b"cidr", "dhcp_options", b"dhcp_options", "gateway_ip", b"gateway_ip", "vrf_id", b"vrf_id"]) -> None: ...

global___VrfOptionsSpec = VrfOptionsSpec

@typing.final
class DhcpOptionsSpec(google.protobuf.message.Message):
    """DHCP options for the private subnet."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_IP_FIELD_NUMBER: builtins.int
    END_IP_FIELD_NUMBER: builtins.int
    start_ip: builtins.str
    """Start IP address of the DHCP range (inclusive).
    The absence or null value indicates that calculation will be performed based on CIDR.
    """
    end_ip: builtins.str
    """End IP address of the DHCP range (inclusive).
    The absence or null value indicates that calculation will be performed based on CIDR.
    """
    def __init__(
        self,
        *,
        start_ip: builtins.str = ...,
        end_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_ip", b"end_ip", "start_ip", b"start_ip"]) -> None: ...

global___DhcpOptionsSpec = DhcpOptionsSpec

@typing.final
class CreatePrivateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the private subnet that is being created."""
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___CreatePrivateSubnetMetadata = CreatePrivateSubnetMetadata

@typing.final
class UpdatePrivateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VRF_OPTIONS_SPEC_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the PrivateSubnet resource to update.

    To get the private subnet ID, use a [PrivateSubnetService.List] request.
    """
    name: builtins.str
    """Name of the private subnet.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the private subnet."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the PrivateSubnet resource are going to be updated."""

    @property
    def vrf_options_spec(self) -> global___VrfOptionsSpec:
        """VRF options. Optional."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        vrf_options_spec: global___VrfOptionsSpec | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask", "vrf_options_spec", b"vrf_options_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "private_subnet_id", b"private_subnet_id", "update_mask", b"update_mask", "vrf_options_spec", b"vrf_options_spec"]) -> None: ...

global___UpdatePrivateSubnetRequest = UpdatePrivateSubnetRequest

@typing.final
class UpdatePrivateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the PrivateSubnet resource that is being updated."""
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___UpdatePrivateSubnetMetadata = UpdatePrivateSubnetMetadata

@typing.final
class DeletePrivateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the private subnet to delete.

    To get the private subnet ID, use a [PrivateSubnetService.List] request.
    """
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___DeletePrivateSubnetRequest = DeletePrivateSubnetRequest

@typing.final
class DeletePrivateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the PrivateSubnet resource that is being deleted."""
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___DeletePrivateSubnetMetadata = DeletePrivateSubnetMetadata

@typing.final
class ListPrivateSubnetOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the PrivateSubnet resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListImageOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListPrivateSubnetOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "private_subnet_id", b"private_subnet_id"]) -> None: ...

global___ListPrivateSubnetOperationsRequest = ListPrivateSubnetOperationsRequest

@typing.final
class ListPrivateSubnetOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListImageOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListImageOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified PrivateSubnet resource."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListPrivateSubnetOperationsResponse = ListPrivateSubnetOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.opensearch.v1.extension_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___GetExtensionRequest = GetExtensionRequest

@typing.final
class ListExtensionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster to list extensions in."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListBackups requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListBackups
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExtensionsRequest = ListExtensionsRequest

@typing.final
class ListExtensionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListBackups requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListBackups request. Subsequent ListBackups
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.opensearch.v1.extension_pb2.Extension]:
        """Requested list of extensions."""

    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.extension_pb2.Extension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExtensionsResponse = ListExtensionsResponse

@typing.final
class DeleteExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___DeleteExtensionRequest = DeleteExtensionRequest

@typing.final
class DeleteExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___DeleteExtensionMetadata = DeleteExtensionMetadata

@typing.final
class UpdateExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension to update."""
    active: builtins.bool
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
        active: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___UpdateExtensionRequest = UpdateExtensionRequest

@typing.final
class UpdateExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___UpdateExtensionMetadata = UpdateExtensionMetadata

@typing.final
class CreateExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    @property
    def extension_spec(self) -> yandex.cloud.mdb.opensearch.v1.extension_pb2.ExtensionSpec: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_spec: yandex.cloud.mdb.opensearch.v1.extension_pb2.ExtensionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["extension_spec", b"extension_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_spec", b"extension_spec"]) -> None: ...

global___CreateExtensionRequest = CreateExtensionRequest

@typing.final
class CreateExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster."""
    extension_id: builtins.str
    """Required. ID of the extension."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___CreateExtensionMetadata = CreateExtensionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.monitoring.v3.dashboard_pb2
import yandex.cloud.monitoring.v3.link_item_pb2
import yandex.cloud.monitoring.v3.parametrization_pb2
import yandex.cloud.monitoring.v3.timeline_pb2
import yandex.cloud.monitoring.v3.widget_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___GetDashboardRequest = GetDashboardRequest

@typing.final
class ListDashboardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required. Folder ID."""
    page_size: builtins.int
    """The maximum number of dashboards to return.
    If unspecified, at most 100 dashboards will be returned.
    The maximum value is 1000; values above 1000 will be coerced to 1000.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDashboardResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """Text substring to find in any of dashboard fields: id, name, etc
    result will include dashboards that meet BOTH filter and selector (see below) criteria
    """
    selectors: builtins.str
    """Selector string to match dashboard fields:
    id, name, description, managed_by, etc, format: FIELDNAME PREDICATE VALUE, FIELDNAME PREDICATE VALUE, ...
    and dashboard labels, format: labels.KEY PREDICATE VALUE, labels.KEY PREDICATE VALUE, ...
    supports GLOB and regex expressions
    dashboard must meet ALL tokens in selector string
    example: name = "New", description = "*new*", labels.key != "bad"
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        selectors: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "selectors", b"selectors"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___ListDashboardsRequest = ListDashboardsRequest

@typing.final
class ListDashboardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results, or empty if there are no more results in the list."""
    @property
    def dashboards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard]:
        """List of dashboards."""

    def __init__(
        self,
        *,
        dashboards: collections.abc.Iterable[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboards", b"dashboards", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDashboardsResponse = ListDashboardsResponse

@typing.final
class CreateDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    WIDGETS_FIELD_NUMBER: builtins.int
    PARAMETRIZATION_FIELD_NUMBER: builtins.int
    MANAGED_BY_FIELD_NUMBER: builtins.int
    MANAGED_LINK_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required. Folder ID."""
    name: builtins.str
    """Required. Dashboard name."""
    description: builtins.str
    """Dashboard description."""
    title: builtins.str
    """Dashboard title."""
    managed_by: builtins.str
    """Entity that controls dashboard
    Must match the regular expression "[\\w \\-]{1,100}"
    """
    managed_link: builtins.str
    """Information about entity that controls dashboard
    Must be valid URI
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.widget_pb2.Widget]:
        """List of dashboard widgets."""

    @property
    def parametrization(self) -> yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization:
        """Dashboard parametrization."""

    @property
    def timeline(self) -> yandex.cloud.monitoring.v3.timeline_pb2.Timeline:
        """Refresh and time window settings"""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem]:
        """Dashboard links"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        title: builtins.str = ...,
        widgets: collections.abc.Iterable[yandex.cloud.monitoring.v3.widget_pb2.Widget] | None = ...,
        parametrization: yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization | None = ...,
        managed_by: builtins.str = ...,
        managed_link: builtins.str = ...,
        timeline: yandex.cloud.monitoring.v3.timeline_pb2.Timeline | None = ...,
        links: collections.abc.Iterable[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id", "parametrization", b"parametrization", "timeline", b"timeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "links", b"links", "managed_by", b"managed_by", "managed_link", b"managed_link", "name", b"name", "parametrization", b"parametrization", "timeline", b"timeline", "title", b"title", "widgets", b"widgets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___CreateDashboardRequest = CreateDashboardRequest

@typing.final
class CreateDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___CreateDashboardMetadata = CreateDashboardMetadata

@typing.final
class UpdateDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    WIDGETS_FIELD_NUMBER: builtins.int
    PARAMETRIZATION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    MANAGED_BY_FIELD_NUMBER: builtins.int
    MANAGED_LINK_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    name: builtins.str
    """Required. Dashboard name."""
    description: builtins.str
    """Dashboard description."""
    title: builtins.str
    """Dashboard title."""
    etag: builtins.str
    """The current etag of the dashboard."""
    managed_by: builtins.str
    """Entity that controls dashboard
    Must match the regular expression "[\\w \\-]{1,100}"
    """
    managed_link: builtins.str
    """Information about entity that controls dashboard
    Must be valid URI
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.widget_pb2.Widget]:
        """List of dashboard widgets."""

    @property
    def parametrization(self) -> yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization:
        """Dashboard parametrization."""

    @property
    def timeline(self) -> yandex.cloud.monitoring.v3.timeline_pb2.Timeline:
        """Refresh and time window settings"""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem]:
        """Dashboard links"""

    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        title: builtins.str = ...,
        widgets: collections.abc.Iterable[yandex.cloud.monitoring.v3.widget_pb2.Widget] | None = ...,
        parametrization: yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization | None = ...,
        etag: builtins.str = ...,
        managed_by: builtins.str = ...,
        managed_link: builtins.str = ...,
        timeline: yandex.cloud.monitoring.v3.timeline_pb2.Timeline | None = ...,
        links: collections.abc.Iterable[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parametrization", b"parametrization", "timeline", b"timeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "description", b"description", "etag", b"etag", "labels", b"labels", "links", b"links", "managed_by", b"managed_by", "managed_link", b"managed_link", "name", b"name", "parametrization", b"parametrization", "timeline", b"timeline", "title", b"title", "widgets", b"widgets"]) -> None: ...

global___UpdateDashboardRequest = UpdateDashboardRequest

@typing.final
class UpdateDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___UpdateDashboardMetadata = UpdateDashboardMetadata

@typing.final
class DeleteDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    etag: builtins.str
    """The current etag of the dashboard."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "etag", b"etag"]) -> None: ...

global___DeleteDashboardRequest = DeleteDashboardRequest

@typing.final
class DeleteDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___DeleteDashboardMetadata = DeleteDashboardMetadata

@typing.final
class ListDashboardOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDashboardOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDashboardOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDashboardOperationsRequest = ListDashboardOperationsRequest

@typing.final
class ListDashboardOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDashboardOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListDashboardOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified dashboard."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDashboardOperationsResponse = ListDashboardOperationsResponse

@typing.final
class ListDashboardLabelNamesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    text: builtins.str
    """Contains substring of name(aka key). All label names containing this string will be returned"""
    selectors: builtins.str
    """Filters alerts by this selectors."""
    page_size: builtins.int
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        text: builtins.str = ...,
        selectors: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "project_id", b"project_id", "selectors", b"selectors", "text", b"text"]) -> None: ...

global___ListDashboardLabelNamesRequest = ListDashboardLabelNamesRequest

@typing.final
class ListDashboardLabelNamesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_NAMES_FIELD_NUMBER: builtins.int
    TRUNCATED_FIELD_NUMBER: builtins.int
    truncated: builtins.bool
    @property
    def label_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        label_names: collections.abc.Iterable[builtins.str] | None = ...,
        truncated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["label_names", b"label_names", "truncated", b"truncated"]) -> None: ...

global___ListDashboardLabelNamesResponse = ListDashboardLabelNamesResponse

@typing.final
class ListDashboardLabelValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    LABEL_NAME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    selectors: builtins.str
    """Filters alerts by this selectors."""
    label_name: builtins.str
    """Contains full name (aka key), for which existing values are gathered."""
    text: builtins.str
    """Contains substring of value. All label values containing this string will be returned"""
    page_size: builtins.int
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        selectors: builtins.str = ...,
        label_name: builtins.str = ...,
        text: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["label_name", b"label_name", "page_size", b"page_size", "project_id", b"project_id", "selectors", b"selectors", "text", b"text"]) -> None: ...

global___ListDashboardLabelValuesRequest = ListDashboardLabelValuesRequest

@typing.final
class ListDashboardLabelValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_VALUES_FIELD_NUMBER: builtins.int
    TRUNCATED_FIELD_NUMBER: builtins.int
    truncated: builtins.bool
    @property
    def label_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        label_values: collections.abc.Iterable[builtins.str] | None = ...,
        truncated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["label_values", b"label_values", "truncated", b"truncated"]) -> None: ...

global___ListDashboardLabelValuesResponse = ListDashboardLabelValuesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/greenplum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/greenplum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/connectionmanager/v1/greenplum.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"i\n\rGreenplumAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xf8\x03\n\x10GreenplumCluster\x12S\n\x11\x63oordinator_hosts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xcc\x02\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12K\n\x04role\x18\x03 \x01(\x0e\x32=.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host.Role\x12O\n\x06health\x18\x04 \x01(\x0e\x32?.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host.Health\"5\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"S\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0e\n\nUNBALANCED\x10\x04\"\xca\x01\n\x13GreenplumConnection\x12\x44\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.GreenplumCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12>\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.connectionmanager.v1.GreenplumAuth\x12\x11\n\tdatabases\x18\x04 \x03(\tB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.greenplum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_GREENPLUMAUTH']._serialized_start=136
  _globals['_GREENPLUMAUTH']._serialized_end=241
  _globals['_GREENPLUMCLUSTER']._serialized_start=244
  _globals['_GREENPLUMCLUSTER']._serialized_end=748
  _globals['_GREENPLUMCLUSTER_HOST']._serialized_start=416
  _globals['_GREENPLUMCLUSTER_HOST']._serialized_end=748
  _globals['_GREENPLUMCLUSTER_HOST_ROLE']._serialized_start=610
  _globals['_GREENPLUMCLUSTER_HOST_ROLE']._serialized_end=663
  _globals['_GREENPLUMCLUSTER_HOST_HEALTH']._serialized_start=665
  _globals['_GREENPLUMCLUSTER_HOST_HEALTH']._serialized_end=748
  _globals['_GREENPLUMCONNECTION']._serialized_start=751
  _globals['_GREENPLUMCONNECTION']._serialized_end=953
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Extension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required. Extension name."""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtensionVersion]:
        """Required. All extension available versions."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        versions: collections.abc.Iterable[global___ExtensionVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "versions", b"versions"]) -> None: ...

global___Extension = Extension

@typing.final
class ExtensionVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    DEPRECATED_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. Version ID."""
    default: builtins.bool
    """Is default version."""
    deprecated: builtins.bool
    """Is version deprecated."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        default: builtins.bool = ...,
        deprecated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default", b"default", "deprecated", b"deprecated", "id", b"id"]) -> None: ...

global___ExtensionVersion = ExtensionVersion
